@@ -27,3 +27,10 @@ def test_progress_bar():
         "                                   ",
         "test |##########| 2/2 [00:00<00:00, dog=good_boi]",
     ]
+
+def test_progress_bar_logs_suppress():
+    # Progress bar should still return logs!
+    with CaptureStdout() as output:
+        for logs, i in progress_bar(range(10),suppress=True, log_values=True):
+            pass
+    assert output == []
